#
# Hardware settings for Teclast F5 10" Laptop
# NixOS @ sda2
#
# flake.nix
#  └─ ./hosts
#      └─ ./laptop
#          └─ hardware-configuration.nix *
#
# Do not modify this file!  It was generated by ‘nixos-generate-config’
# and may be overwritten by future invocations.  Please make changes
# to /etc/nixos/configuration.nix instead.
{ config, lib, pkgs, modulesPath, ... }:

{
  imports =
    [ (modulesPath + "/profiles/qemu-guest.nix")
    ];

  boot.initrd.availableKernelModules = [  "ata_piix" "uhci_hcd" "virtio_pci" "virtio_scsi" "ahci" "sd_mod" "sr_mod" ];
  boot.initrd.kernelModules = [ "vfio_pci" "vfio" "vfio_iommu_type1" ];
  boot.kernelModules = [ "kvm-amd" ];
  boot.extraModulePackages = [ ];
  boot.tmp.useTmpfs = false;
  boot.tmp.cleanOnBoot = true;
  zramSwap.enable = true;

  services.btrfs.autoScrub = {
    enable = true;
    interval = "monthly";
    fileSystems = [
      "/"
    ];
  };

  services.btrbk = {
      instances = {
          hf = {
              onCalendar = "hourly";
              settings = {
                  incremental = "yes";
                  snapshot_create = "ondemand";
                  snapshot_dir = "@snapshots";
                  timestamp_format = "long";

                  snapshot_preserve = "2m 2w 5d 5h";
                  snapshot_preserve_min = "latest";
                
                  volume =  {
                      "/mnt/snapshots/root" = {
                          snapshot_create = "always";
                          subvolume = {
                              "@" = {};
                              "@home" = {};
                          };
                      };
                  };
              };
          };
      };
  };

  fileSystems."/" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@,discard=async" ];
    };

  fileSystems."/home" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@home,discard=async" ];
    };

  fileSystems."/srv" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@srv,discard=async" ];
    };

  fileSystems."/var" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "space_cache=v2,ssd,noatime,subvol=@var,discard=async" ];
    };

  fileSystems."/nix" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@nix,discard=async" ];
    };

  fileSystems."/swap" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@swap,discard=async" ];
    };

  fileSystems."/mnt/snapshots/root" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvolid=5,discard=async" ];
    };


  #swapDevices = [ { device = "/swap/swapfile"; } ];
  swapDevices = [  ];
  
  networking = {
    useDHCP = false;                        # Deprecated
    hostName = "kabtop";
    domain = "kabtop.de";
    networkmanager = {
      enable = false;
    };
    interfaces = {
      ens18 = {
        useDHCP = false;                     # For versatility sake, manually edit IP on nm-applet.
        ipv4.addresses = [ {
            address = "37.44.215.182";
            prefixLength = 24;
        } ];
        ipv6.addresses = [ {
            address = "2a13:7e80:0:ef::2";
            prefixLength = 64;
        } ];
      };
    };
    defaultGateway = "37.44.215.1";
    defaultGateway6 = {
      address = "fe80::1";
      interface = "ens18";
    };

    nameservers = [ "9.9.9.9" "2620:fe::fe" ];
    firewall = {
      enable = true;
      allowedUDPPorts = [  ];
      allowedTCPPorts = [ 80 443 ];
    };
  };

  hardware.cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
